## -*- coding: utf-8 -*- <%inherit file="/base/base.html"/> <%def name="title()"> ${_('%s Changelog') % c.repo_name} %if c.changelog_for_path: /${c.changelog_for_path} %endif %if c.site_name: · ${c.site_name} %endif <%def name="breadcrumbs_links()"> <% size = c.size if c.size <= c.total_cs else c.total_cs %> ${_('Changelog')} %if c.changelog_for_path: - /${c.changelog_for_path} %endif %if c.revision: @ ${h.short_id(c.first_revision.raw_id)} %endif - ${ungettext('showing %d out of %d revision', 'showing %d out of %d revisions', size) % (size, c.total_cs)} <%def name="page_nav()"> ${self.menu('repositories')} <%def name="main()"> ${self.repo_context_bar('changelog', c.first_revision.raw_id if c.first_revision else None)}
${self.breadcrumbs()}
% if c.pagination:
${h.form(h.url.current(),method='get')} ${h.submit('set',_('Show'),class_="btn btn-small")} ${h.text('size',size=3,value=c.size)} ${_('revisions')} %if c.branch_name: ${h.hidden('branch', c.branch_name)} %endif ${h.end_form()}
${_('Clear selection')} %if c.revision: ${_('Go to tip of repository')} %endif %if c.db_repo.fork: ${_('Compare fork with parent repo (%s)' % c.db_repo.fork.repo_name)} %endif ## text and href of open_new_pr is controlled from javascript ${_("Branch filter:")} ${h.select('branch_filter',c.branch_name,c.branch_filters)}

%for cnt,cs in enumerate(c.pagination):
%if c.changelog_for_path: ${h.checkbox(cs.raw_id,class_="changeset_range", disabled="disabled")} %else: ${h.checkbox(cs.raw_id,class_="changeset_range")} %endif | %if c.statuses.get(cs.raw_id): %if c.statuses.get(cs.raw_id)[2]: %else: %endif %endif | ${h.shorter(h.person(cs.author),22)} | ${h.show_id(cs)} | ${h.age(cs.date,True)} |  | ${h.urlify_commit(cs.message, c.repo_name,h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} %if c.comments.get(cs.raw_id): ${len(c.comments[cs.raw_id])} %endif %if h.is_hg(c.db_repo_scm_instance): %for book in cs.bookmarks: ${h.link_to(book,h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} %endfor %endif %for tag in cs.tags: ${h.link_to(tag,h.url('changeset_home',repo_name=c.repo_name,revision=cs.raw_id))} %endfor %if (not c.branch_name) and cs.branch: ${h.link_to(cs.branch,h.url('changelog_home',repo_name=c.repo_name,branch=cs.branch))} %endif
%endfor

${c.pagination.pager('$link_previous ~2~ $link_next')}
%else: ${_('There are no changes yet')} %endif